@@ -11,6 +11,7 @@ from builtins import object
 import socket, math, struct, time, os, fnmatch, array, sys, errno
 import select
 import copy
+import json
 import re
 from pymavlink import mavexpression
 
@@ -20,7 +21,6 @@ is_py3 = sys.version_info >= (3,0)
 # without having complex spec files. To allow for installs that don't have ardupilotmega
 # at all we avoid throwing an exception if it isn't installed
 try:
-    import json
     from pymavlink.dialects.v10 import ardupilotmega
 except Exception:
     pass
@@ -1531,11 +1531,11 @@ class mavmmaplog(mavlogfile):
                 self.offsets[mtype] = []
                 self.counts[mtype] = 0
                 msg = mavlink.mavlink_map[mtype]
-                self.name_to_id[msg.name] = mtype
-                self.id_to_name[mtype] = msg.name
+                self.name_to_id[msg.msgname] = mtype
+                self.id_to_name[mtype] = msg.msgname
                 self.f.seek(ofs)
                 m = self.recv_msg()
-                add_message(self.messages, msg.name, m)
+                add_message(self.messages, msg.msgname, m)
                 if m._instance_field is not None:
                     instance_idx = m.ordered_fieldnames.index(m._instance_field)
                     self.instance_offsets[mtype] = m._instance_offset
@@ -1571,7 +1571,7 @@ class mavmmaplog(mavlogfile):
                         b = b[:-1]
                     instance = b.decode('ASCII',errors='ignore').rstrip()
                 else:
-                    instance, = struct.unpack('b', b)
+                    instance, = struct.unpack('b', b[:1])
                 mname = self.id_to_name[mtype]
                 if mname in self.messages:
                     iname = "%s[%s]" % (mname, str(instance))
